@@ -289,7 +289,7 @@ ui <- fluidPage(
                                 bsPopover(
                                   id = "share_decision",
                                   title = "Share Help",
-                                  content = c("If you lile, we share your uploaded spectra and settings with the spectroscopy community.",
+                                  content = c("If you like, we share your uploaded spectra and settings with the spectroscopy community.",
                                               "By default, all data will be licensed under Creative Commons Attribution-NonCommercial 4.0 International (CC BY-NC 4.0).",
                                               "Uploaded spectra will appear here: https://osf.io/rjg3c"),
                                   placement = "bottom",
@@ -524,7 +524,7 @@ ui <- fluidPage(
                                     ),
                                 column(2,
                                        dropdownButton(inputId = "baseline_tools",
-                                                      sliderInput("baseline", "Baseline Correction Polynomial", min = 0, max = 20, value = 8),
+                                                      sliderInput("baseline", "Baseline Correction Polynomial", min = 1, max = 20, value = 8),
                                                       icon = icon("gear"),
                                                       size = "xs",
                                                       status = "success",
@@ -552,18 +552,18 @@ ui <- fluidPage(
                                   column(2,
                                          dropdownButton(inputId = "range_tools",
                                                         numericInput(
-                                                          "MinRange",
-                                                          "Minimum Spectral Range",
-                                                          value = 0,
+                                                          "MaxRange",
+                                                          "Maximum Spectral Range",
+                                                          value = 6000,
                                                           min = NA,
                                                           max = NA,
                                                           step = NA,
                                                           width = NULL
                                                         ),
                                                         numericInput(
-                                                          "MaxRange",
-                                                          "Maximum Spectral Range",
-                                                          value = 6000,
+                                                          "MinRange",
+                                                          "Minimum Spectral Range",
+                                                          value = 0,
                                                           min = NA,
                                                           max = NA,
                                                           step = NA,
