@@ -1,5 +1,5 @@
 # Create temp dir for testthat
-tmp <- file.path(tempdir(), "testthat")
+tmp <- file.path(tempdir(), "OpenSpecy-testthat")
 dir.create(tmp, showWarnings = F)
 
 test_that("extdata files are present", {
